tsseg.algorithms.ticc package
=============================

Joint learning of Toeplitz-structured inverse covariance matrices per cluster with
temporal consistency penalty.

| **Type:** state detection
| **Supervision:** semi-supervised
| **Scope:** multivariate, transductive

**Implementation:** Taken from https://github.com/davidhallac/TICC. No licence
specified.

**Reference:** Hallac, Vare, Boyd & Leskovec (2017), KDD.

Submodules
----------

tsseg.algorithms.ticc.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.ticc.detector
   :members:
   :show-inheritance:
   :undoc-members:

tsseg.algorithms.ticc.ticc module
---------------------------------

.. automodule:: tsseg.algorithms.ticc.ticc
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.ticc
   :members:
   :show-inheritance:
   :undoc-members:
